package icontrols.DataGrid;

import com.ms.wd.ui.Brush;
import com.ms.wd.ui.Color;
import com.ms.wd.ui.Font;
import com.ms.wd.ui.Graphics;
import com.ms.wd.ui.Pen;
import com.ms.wd.ui.Rectangle;
import icontrols.CustomDrawData;
import icontrols.Displayer;
import icontrols.StringDisplayer;

final class CellDisplayer extends Displayer {
   private static final int PEN_SELECTEDBACK = 0;
   private static final int PEN_SELECTEDFORE = 1;
   private static final int PEN_BACK = 2;
   private static final int PEN_FORE = 3;
   protected StringDisplayer m_stringDisplayer = new StringDisplayer();
   protected Pen m_framePen = null;
   protected Pen[] m_penCache = new Pen[4];
   private boolean m_mouseOver = false;
   private boolean m_focus = false;
   private boolean m_selected = false;
   private boolean m_wrap = false;
   private Column m_column = null;

   public boolean isHasFocus() {
      return this.m_focus;
   }

   public void setSelected(boolean bSelected) {
      this.m_selected = bSelected;
      this.setColors();
   }

   protected CellDisplayer(Column column) {
      if (column == null) {
         throw new IllegalArgumentException("Can't have null column");
      } else {
         this.m_column = column;
         this.setMouseOver(false);
         this.setHasFocus(false);
         this.m_stringDisplayer.setUseEllipsis(true);
      }
   }

   public boolean isSelected() {
      return this.m_selected;
   }

   public Color getForeColor() {
      return this.m_column.getForeColor();
   }

   public void paintIn(Graphics g, Rectangle bounds, Rectangle clipRect, CustomDrawData data) {
      CellDrawData cellData = (CellDrawData)data;
      this.setMouseOver(cellData.m_mouseOver);
      this.setHasFocus(cellData.m_focus);
      this.setSelected(cellData.m_selected);
      this.paintIn(g, bounds, clipRect, cellData.m_value);
   }

   public void paintIn(Graphics g, Rectangle bounds, Rectangle clipRect, String str) {
      this.setColors();
      g.setBrush((Brush)null);
      g.setPen(this.m_framePen);
      g.drawRect(bounds);
      this.m_stringDisplayer.setAlignment(this.getAlignment());
      this.m_stringDisplayer.paintIn(g, new Rectangle(bounds.x + 1, bounds.y + 1, bounds.width - 2, bounds.height - 2), clipRect, str);
   }

   public void setMouseOver(boolean bOver) {
      this.m_mouseOver = bOver;
      this.setColors();
   }

   public void setWrap(boolean wrap) {
      this.m_wrap = wrap;
      this.m_stringDisplayer.setWrap(wrap);
   }

   public Font getFont() {
      return this.m_column.getFont();
   }

   private void setPen(int pen) {
      if (this.m_penCache[pen] == null) {
         Pen newPen = null;
         switch (pen) {
            case 0:
               newPen = new Pen(this.getSelectedBackColor());
               break;
            case 1:
               newPen = new Pen(this.getSelectedForeColor());
               break;
            case 2:
               newPen = new Pen(this.getBackColor());
               break;
            case 3:
               newPen = new Pen(this.getForeColor());
         }

         this.m_penCache[pen] = newPen;
      }

      this.m_framePen = this.m_penCache[pen];
   }

   public Color getSelectedForeColor() {
      return this.m_column.getSelectedForeColor();
   }

   public Color getBackColor() {
      return this.m_column.getBackColor();
   }

   public boolean isWrap() {
      return this.m_wrap;
   }

   public Color getSelectedBackColor() {
      return this.m_column.getSelectedBackColor();
   }

   public boolean isMouseOver() {
      return this.m_mouseOver;
   }

   public void setHasFocus(boolean bFocus) {
      this.m_focus = bFocus;
      this.setColors();
   }

   public void clearColorCache() {
      for(int i = 0; i < this.m_penCache.length; ++i) {
         this.m_penCache[i] = null;
      }

   }

   public void eventHandler(CellDrawEvent event) {
      this.paintIn(event.graphics, event.bounds, event.clipRect, (CustomDrawData)event.data);
   }

   private void setColors() {
      StringDisplayer disp = this.m_stringDisplayer;
      if (!this.getFont().equals(this.m_column.m_parent.getFont())) {
         disp.setFont(this.getFont());
      } else {
         disp.setFont((Font)null);
      }

      if (this.m_selected) {
         disp.setBackColor(this.getSelectedBackColor());
         disp.setForeColor(this.getSelectedForeColor());
         if (this.m_focus) {
            this.setPen(1);
         } else {
            this.setPen(0);
         }
      } else {
         disp.setBackColor(this.getBackColor());
         disp.setForeColor(this.getForeColor());
         if (this.m_focus) {
            this.setPen(3);
         } else {
            this.setPen(2);
         }
      }

      if (this.m_mouseOver) {
         disp.setForeColor(Color.HOTTRACK);
      }

   }

   public int getAlignment() {
      return this.m_column.getAlignment();
   }

   public void setColumn(Column column) {
      this.m_column = column;
   }
}
