package icontrols.DataGrid;

import com.ms.ado.Field;
import com.ms.wd.core.Closure;
import com.ms.wd.ui.Color;
import com.ms.wd.ui.Font;
import com.ms.wd.util.Debug;
import icontrols.Data.DataProvider;
import icontrols.Data.DataRow;

public final class Column {
   public static final int ALIGN_LEFT = 1;
   public static final int ALIGN_RIGHT = 2;
   public static final int ALIGN_HCENTER = 4;
   public static final int ALIGN_TOP = 16;
   public static final int ALIGN_BOTTOM = 32;
   public static final int ALIGN_VCENTER = 64;
   public static final int ALIGN_NONE = Integer.MIN_VALUE;
   protected static final int PROP_ALIGNMENT = 1;
   protected static final int PROP_ALLOWSIZING = 2;
   protected static final int PROP_BOUNDCOLUMN = 3;
   protected static final int PROP_BACKCOLOR = 4;
   protected static final int PROP_WIDTH = 5;
   protected static final int PROP_CAPTION = 6;
   protected static final int PROP_INDEX = 7;
   protected static final int PROP_DATATYPE = 8;
   protected static final int PROP_FORECOLOR = 10;
   protected static final int PROP_LEFT = 9;
   protected static final int PROP_READONLY = 11;
   protected static final int PROP_SELBACKCOLOR = 12;
   protected static final int PROP_SELFORECOLOR = 13;
   protected static final int PROP_VALUE = 14;
   protected static final int PROP_WRAPTEXT = 16;
   protected static final int PROP_HEADERDRAW = 17;
   protected static final int PROP_CELLDRAW = 18;
   protected static final int PROP_FONT = 19;
   protected static final int PROP_VISIBLE = 20;
   protected CellDrawEventHandler m_cellDraw = null;
   protected ColumnHeaderDrawEventHandler m_headerDraw = null;
   protected CellDisplayer m_cellDisplayer = null;
   protected ColumnHeaderDisplayer m_headerDisplayer = new ColumnHeaderDisplayer();
   protected ICellEditor m_editor = new DataGridTextEditor();
   protected int m_dbColumnId = -1;
   protected String m_caption = null;
   protected int m_width = 55;
   protected int m_x = 0;
   protected boolean m_wrap = false;
   protected DataGrid m_parent = null;
   protected Font m_font = null;
   protected Color m_foreColor = null;
   protected Color m_backColor = null;
   protected Color m_selectedForeColor = null;
   protected Color m_selectedBackColor = null;
   private boolean m_allowSizing = true;
   private String m_boundFieldName = null;
   private int m_alignment = Integer.MIN_VALUE;
   private boolean m_visible = true;
   private Field m_boundReadField = null;
   private Field m_boundWriteField = null;
   private boolean m_readonly = false;
   private int m_index = -1;

   protected Field getBoundWriteField() {
      if (this.m_boundWriteField == null && this.m_dbColumnId != -1) {
         DataProvider dp = this.m_parent.getDataProvider();
         this.m_boundWriteField = dp.getWriteField(this.m_dbColumnId);
      }

      return this.m_boundWriteField;
   }

   public boolean isReadOnly() {
      return this.m_readonly;
   }

   public void setAllowSizing(boolean allow) {
      this.m_allowSizing = allow;
   }

   public Color getBackColor() {
      return this.m_backColor == null ? this.m_parent.getBackColor() : this.m_backColor;
   }

   public Color getSelectedForeColor() {
      return this.m_selectedForeColor == null ? this.m_parent.getSelectedForeColor() : this.m_selectedForeColor;
   }

   public void setBackColor(Color color) {
      this.m_backColor = color;
      this.m_cellDisplayer.clearColorCache();
      this.m_parent.columnPropertyChange(4, this);
   }

   public void addOnCellDraw(CellDrawEventHandler draw) {
      this.m_cellDraw = (CellDrawEventHandler)Closure.combine(draw, this.m_cellDraw);
      this.m_parent.columnPropertyChange(18, this);
   }

   public void setSelectedForeColor(Color color) {
      this.m_selectedForeColor = color;
      this.m_cellDisplayer.clearColorCache();
      this.m_parent.columnPropertyChange(13, this);
   }

   public Color getSelectedBackColor() {
      return this.m_selectedBackColor == null ? this.m_parent.getSelectedBackColor() : this.m_selectedBackColor;
   }

   public void setSelectedBackColor(Color color) {
      this.m_selectedBackColor = color;
      this.m_cellDisplayer.clearColorCache();
      this.m_parent.columnPropertyChange(12, this);
   }

   public boolean isVisible() {
      return this.m_visible;
   }

   protected Field getBoundReadField() {
      if (this.m_boundReadField == null && this.m_dbColumnId != -1) {
         DataProvider dp = this.m_parent.getDataProvider();
         this.m_boundReadField = dp.getReadField(this.m_dbColumnId);
      }

      return this.m_boundReadField;
   }

   public String getBoundFieldName() {
      return this.m_boundFieldName;
   }

   public void setBoundFieldName(String name) {
      String oldName = this.m_boundFieldName;
      this.m_boundFieldName = name;

      try {
         this.updateBindingFromName();
      } catch (Exception var4) {
         this.m_boundFieldName = oldName;
         this.updateBindingFromName();
      }

      this.m_parent.columnPropertyChange(3, this);
   }

   protected void ambientsChanged() {
      if (this.m_selectedForeColor == null || this.m_selectedBackColor == null || this.m_foreColor == null || this.m_backColor == null || this.m_font == null) {
         this.m_cellDisplayer.clearColorCache();
      }

   }

   public int getWidth() {
      return this.m_width;
   }

   public void setWidth(int width) {
      if (width != this.m_width && this.m_allowSizing) {
         if (width < 15) {
            throw DataGridException.invalidColumnWidth();
         }

         ColumnResizeEvent resize = null;
         resize = new ColumnResizeEvent(this.m_index, width, false);
         this.m_parent.onColumnResize(resize);
         if (!resize.cancel) {
            this.m_width = width;
            this.m_parent.columnPropertyChange(5, this);
         }
      }

   }

   public void setReadOnly(boolean readonly) {
      if (this.m_readonly != readonly) {
         this.m_readonly = readonly;
         this.m_parent.columnPropertyChange(11, this);
      }

   }

   public void removeOnColumnHeaderDraw(ColumnHeaderDrawEventHandler draw) {
      this.m_headerDraw = (ColumnHeaderDrawEventHandler)Closure.remove(this.m_headerDraw, draw);
      this.m_parent.columnPropertyChange(17, this);
   }

   public String getCaption() {
      return this.m_caption;
   }

   public void setCaption(String caption) {
      this.m_caption = caption;
      this.m_headerDisplayer.setCaption(caption);
      this.m_parent.columnPropertyChange(6, this);
   }

   public String getValue() {
      Field field = this.getBoundReadField();
      if (field != null) {
         DataRow current = this.m_parent.getDataProvider().getCurrentRow();
         return this.m_parent.getDataProvider().getFormattedData(this.m_parent.getDataProvider().getCurrentRow(), field);
      } else {
         return null;
      }
   }

   public void setValue(String value) {
      Field field = this.getBoundWriteField();
      if (field != null) {
         this.m_parent.getDataProvider().setFormattedData(this.getBoundWriteField(), value);
      }

   }

   public void addOnColumnHeaderDraw(ColumnHeaderDrawEventHandler draw) {
      this.m_headerDraw = (ColumnHeaderDrawEventHandler)Closure.combine(draw, this.m_headerDraw);
      this.m_parent.columnPropertyChange(17, this);
   }

   protected Column(DataGrid parent, String boundFieldName) {
      if (parent == null) {
         throw new IllegalArgumentException("Can't have null parent on column");
      } else if (boundFieldName == null) {
         throw new IllegalArgumentException("Can't have null bound column");
      } else {
         this.m_parent = parent;
         this.m_caption = boundFieldName;
         this.m_boundFieldName = boundFieldName;
         this.m_headerDisplayer.setMouseOver(false);
         if (this.m_caption != null) {
            this.m_headerDisplayer.setCaption(this.m_caption);
         }

         this.m_cellDisplayer = new CellDisplayer(this);
      }
   }

   protected void rebind() {
      try {
         this.updateBindingFromName();
      } catch (IllegalArgumentException var2) {
      }

   }

   public Color getForeColor() {
      return this.m_foreColor == null ? this.m_parent.getForeColor() : this.m_foreColor;
   }

   public void setForeColor(Color color) {
      this.m_foreColor = color;
      this.m_cellDisplayer.clearColorCache();
      this.m_parent.columnPropertyChange(10, this);
   }

   public void removeOnCellDraw(CellDrawEventHandler draw) {
      this.m_cellDraw = (CellDrawEventHandler)Closure.remove(this.m_cellDraw, draw);
      this.m_parent.columnPropertyChange(18, this);
   }

   public String toString() {
      return this.getClass().getName() + "[" + this.m_boundFieldName + ", " + this.m_dbColumnId + ", " + this.m_index + "]";
   }

   public void setVisible(boolean visible) {
      if (this.m_visible != visible) {
         this.m_visible = visible;
         this.m_parent.columnPropertyChange(20, this);
      }

   }

   private void updateBindingFromName() {
      DataProvider data = this.m_parent.getDataProvider();
      Debug.assert(this.m_boundFieldName != null, "Bound column can't be null");
      this.m_dbColumnId = -1;
      this.m_boundReadField = null;
      this.m_boundWriteField = null;
      if (data != null) {
         Field bound = data.getReadField(this.m_boundFieldName);
         if (bound != null) {
            for(int i = 0; i < data.getColumnCount(); ++i) {
               if (this.m_boundFieldName.equals(data.getReadField(i).getName())) {
                  this.m_dbColumnId = i;
                  break;
               }
            }
         }

         if (this.m_dbColumnId < 0) {
            this.setVisible(false);
            String availableNames = "(Available names are: ";

            for(int i = 0; i < data.getColumnCount(); ++i) {
               availableNames = availableNames + "[" + data.getReadField(i).getName() + "] ";
            }

            availableNames = availableNames + ")";
            throw new IllegalArgumentException("Column [" + this.m_boundFieldName + "] not found in datasource " + availableNames);
         }
      }
   }

   public Font getFont() {
      return this.m_font == null ? this.m_parent.getFont() : this.m_font;
   }

   public void setFont(Font font) {
      this.m_font = font;
      this.m_cellDisplayer.clearColorCache();
      this.m_parent.columnPropertyChange(19, this);
   }

   public boolean isAllowSizing() {
      return this.m_allowSizing;
   }

   public int getIndex() {
      return this.m_index;
   }

   protected void internalSetIndex(int index) {
      this.m_index = index;
   }

   public void setIndex(int index) {
      if (this.m_index != index) {
         this.internalSetIndex(index);
         this.m_parent.columnPropertyChange(7, this);
      }

   }

   public int getLeft() {
      return this.m_x;
   }

   public void setWrapText(boolean wrap) {
      this.m_wrap = wrap;
      this.m_cellDisplayer.setWrap(wrap);
      this.m_parent.columnPropertyChange(16, this);
   }

   public int getAlignment() {
      return this.m_alignment;
   }

   private boolean isAlignmentValid(int align) {
      int combine = -2147483529;
      return align != 0 && (align & ~combine) == 0;
   }

   public void setAlignment(int align) {
      if (this.m_alignment != align) {
         if (!this.isAlignmentValid(align)) {
            throw DataGridException.invalidAlignment();
         }

         this.m_alignment = align;
         this.m_parent.columnPropertyChange(1, this);
      }

   }

   public boolean isWrapText() {
      return this.m_wrap;
   }

   public int getDataType() {
      Field field = this.getBoundReadField();
      return field != null ? field.getType() : -1;
   }
}
