package icontrols.DataGrid;

import com.ms.wd.ui.Color;
import com.ms.wd.ui.Font;
import com.ms.wd.ui.Graphics;
import com.ms.wd.ui.Rectangle;
import com.ms.wd.win32.RECT;
import com.ms.wd.win32.Windows;
import icontrols.CustomDrawData;
import icontrols.Displayer;
import icontrols.StringDisplayer;

final class ColumnHeaderDisplayer extends Displayer {
   private StringDisplayer m_stringDisplayer = new StringDisplayer();
   private boolean m_mouseOver = false;
   private String m_caption = "";
   private Font m_font = null;
   private boolean m_wrap = false;
   private RECT m_rect = new RECT();

   public String getCaption() {
      return this.m_caption;
   }

   public void setCaption(String caption) {
      this.m_caption = caption;
   }

   protected ColumnHeaderDisplayer() {
      this.m_stringDisplayer.setBackColor(Color.CONTROL);
      this.m_stringDisplayer.setUseEllipsis(true);
      this.setMouseOver(false);
   }

   public void paintIn(Graphics g, Rectangle bounds, Rectangle clipRect, CustomDrawData data) {
      ColumnHeaderDrawData headerData = (ColumnHeaderDrawData)data;
      this.paintIn(g, bounds, clipRect, headerData.caption);
   }

   public void paintIn(Graphics g, Rectangle bounds, Rectangle clipRect, String str) {
      RECT rc = this.m_rect;
      rc.left = bounds.x;
      rc.top = bounds.y;
      rc.right = bounds.x + bounds.width;
      rc.bottom = bounds.y + bounds.height;
      Windows.DrawEdge(g.getHandle(), rc, 5, 15);
      bounds.x += 2;
      bounds.y += 2;
      bounds.width -= 4;
      bounds.height -= 4;
      String display = "";
      if (str != null) {
         display = str;
      } else if (this.m_caption != null) {
         display = this.m_caption;
      }

      this.m_stringDisplayer.paintIn(g, bounds, clipRect, display);
   }

   public void setMouseOver(boolean over) {
      StringDisplayer dispString = this.m_stringDisplayer;
      if (over) {
         dispString.setForeColor(Color.HOTTRACK);
      } else {
         dispString.setForeColor(Color.CONTROLTEXT);
      }

      this.m_mouseOver = over;
   }

   public boolean getWrap() {
      return this.m_wrap;
   }

   public void setWrap(boolean wrap) {
      this.m_wrap = wrap;
      this.m_stringDisplayer.setWrap(wrap);
   }

   public Font getFont() {
      return this.m_font;
   }

   public void setFont(Font font) {
      this.m_font = font;
      StringDisplayer dispString = this.m_stringDisplayer;
      dispString.setFont(font);
   }

   public boolean isMouseOver() {
      return this.m_mouseOver;
   }

   public void eventHandler(ColumnHeaderDrawEvent event) {
      this.paintIn(event.graphics, event.bounds, event.clipRect, (CustomDrawData)event.data);
   }
}
