package icontrols.DataGrid;

import com.ms.wd.ui.Color;
import com.ms.wd.ui.Graphics;
import com.ms.wd.ui.Pen;
import com.ms.wd.ui.Rectangle;
import icontrols.Data.DataProvider;

final class GridLineDisplayer {
   public static final int GL_SINGLELINE = 1;
   public static final int GL_3DLINE = 2;
   public static final int GL_NONE = 4;
   public static final int GL_SUNKEN = 16;
   public static final int GL_RAISED = 32;
   private int m_lineStyle = 1;

   protected GridLineDisplayer() {
   }

   protected int getLineStyle() {
      return this.m_lineStyle;
   }

   protected void paintIn(Graphics g, Rectangle bounds, Rectangle clipRect, DataGrid grid) {
      if ((this.m_lineStyle & 4) != 4) {
         Rectangle inside = bounds;
         int horizOffset = grid.getHorizOffset();
         int lineWidth = this.getLineWidth();
         int lineHeight = this.getLineHeight();
         int columnCount = grid.getColumnCount();
         int xOffset = lineWidth / 2;
         int yOffset = lineHeight / 2 + 1;
         int bottomEndOfContent = 0;
         int rightEndOfContent = 0;
         int columnHeaderHeight = grid.getColumnHeaderHeight();
         int rowHeightWithLine = grid.getRowHeight() + lineHeight;
         DataProvider dp = grid.getDataProvider();
         int lastRow = dp.getLastDisplayIndex();
         if (lastRow < 0) {
            bottomEndOfContent = bounds.y + bounds.height;
         } else {
            bottomEndOfContent = columnHeaderHeight + bounds.y + rowHeightWithLine * (grid.getBottomRow() + 1);
            if (bottomEndOfContent > bounds.y + bounds.height) {
               bottomEndOfContent = bounds.y + bounds.height;
            }
         }

         if (columnCount > 0) {
            rightEndOfContent = grid.getInternalColumn(columnCount - 1).m_x + grid.getInternalColumn(columnCount - 1).m_width + lineWidth;
         }

         if ((this.m_lineStyle & 1) == 1) {
            g.setPen(new Pen(Color.WINDOWTEXT, 0, lineWidth));
            int xMin = Math.max(grid.getRowSelectorWidth() + bounds.x, clipRect.x);
            int xMax = Math.max(grid.getRowSelectorWidth() + bounds.x, clipRect.x + clipRect.width);

            for(int column = 0; column < columnCount; ++column) {
               Column colCurrent = grid.getInternalColumn(column);
               int xDrawLoc = colCurrent.m_x + colCurrent.m_width + xOffset;
               if (xDrawLoc >= xMin && xDrawLoc <= xMax) {
                  g.drawLine(xDrawLoc, inside.y, xDrawLoc, bottomEndOfContent);
               }
            }

            int yMin = clipRect.y;
            int yMax = clipRect.y + clipRect.height;
            int yDrawLoc = inside.y + columnHeaderHeight - yOffset;
            int bottomRow = grid.getBottomRow();

            for(int row = 0; row <= bottomRow; ++row) {
               yDrawLoc += rowHeightWithLine;
               if (yDrawLoc >= yMin && yDrawLoc <= yMax) {
                  g.drawLine(inside.x, yDrawLoc, rightEndOfContent, yDrawLoc);
               }
            }
         } else if ((this.m_lineStyle & 2) == 2) {
            Color insideColor;
            Color outsideColor;
            if ((this.m_lineStyle & 16) == 16) {
               insideColor = Color.CONTROL;
               outsideColor = Color.CONTROLDARK;
            } else {
               insideColor = Color.CONTROLDARK;
               outsideColor = Color.CONTROL;
            }

            g.setPen(new Pen(insideColor, 0, 1));

            for(int column = 0; column < columnCount; ++column) {
               Column colCurrent = grid.getInternalColumn(column);
               g.drawLine(colCurrent.m_x + colCurrent.m_width + xOffset, inside.y, colCurrent.m_x + colCurrent.m_width + xOffset, bottomEndOfContent);
            }

            --xOffset;
            g.setPen(new Pen(outsideColor, 0, 1));

            for(int column = 0; column < columnCount; ++column) {
               Column colCurrent = grid.getInternalColumn(column);
               g.drawLine(colCurrent.m_x + colCurrent.m_width + xOffset, inside.y, colCurrent.m_x + colCurrent.m_width + xOffset, bottomEndOfContent);
            }

            g.setPen(new Pen(outsideColor, 0, 1));

            for(int row = 0; row <= grid.getBottomRow(); ++row) {
               g.drawLine(inside.x, inside.y + columnHeaderHeight + (1 + row) * rowHeightWithLine - yOffset, rightEndOfContent, inside.y + columnHeaderHeight + (1 + row) * rowHeightWithLine - yOffset);
            }

            --yOffset;
            g.setPen(new Pen(insideColor, 0, 1));

            for(int row = 0; row <= grid.getBottomRow(); ++row) {
               g.drawLine(inside.x, inside.y + columnHeaderHeight + (1 + row) * rowHeightWithLine - yOffset, rightEndOfContent, inside.y + columnHeaderHeight + (1 + row) * rowHeightWithLine - yOffset);
            }
         }

      }
   }

   protected void setLineStyle(int style) {
      this.m_lineStyle = style;
   }

   protected int getLineHeight() {
      return this.getLineWidth();
   }

   protected int getLineWidth() {
      if ((this.m_lineStyle & 1) != 0) {
         return 1;
      } else {
         return (this.m_lineStyle & 2) != 0 ? 2 : 0;
      }
   }
}
