package icontrols.DataGrid;

import com.ms.wd.ui.Bitmap;
import com.ms.wd.ui.Brush;
import com.ms.wd.ui.Color;
import com.ms.wd.ui.Graphics;
import com.ms.wd.ui.Pen;
import com.ms.wd.ui.Point;
import com.ms.wd.ui.Rectangle;
import com.ms.wd.win32.RECT;
import com.ms.wd.win32.Windows;
import icontrols.CustomDrawData;
import icontrols.Displayer;
import icontrols.ImageDisplayer;

final class RowSelectorDisplayer extends Displayer {
   private boolean m_current = false;
   private boolean m_new = false;
   private boolean m_edit = false;
   private Bitmap m_glyph = null;
   private ImageDisplayer m_imageDisplayer = new ImageDisplayer();
   private int m_height = 8;
   private int m_width = 8;
   private boolean m_mouseOver = false;
   private Brush m_controlBrush;
   private RECT m_rect;
   private static final int BORDERSIZE = 2;

   public boolean isEditRow() {
      return this.m_edit;
   }

   public void setNewRow(boolean bIsNew) {
      if (this.m_new != bIsNew) {
         this.m_new = bIsNew;
         this.updateGlyph();
      }

   }

   private void updateGlyph() {
      int nInnerHeight = this.m_height - 4;
      int nInnerWidth = this.m_width - 4;
      int nMinDimension = Math.min(nInnerWidth, nInnerHeight);
      int nXOffset = 1;
      int nYOffset = 1;
      if (nInnerWidth == nMinDimension) {
         nYOffset = (nInnerHeight - nMinDimension) / 2;
      } else {
         nXOffset = (nInnerWidth - nMinDimension / 2) / 2;
      }

      Color colorPen = null;
      if (this.m_mouseOver) {
         colorPen = Color.HOTTRACK;
      } else {
         colorPen = Color.WINDOWTEXT;
      }

      if (this.m_glyph != null) {
         this.m_glyph = null;
      }

      if (this.m_current) {
         this.m_new = false;
         this.m_edit = false;
         this.m_glyph = new Bitmap(nInnerWidth, nInnerHeight);
         Graphics g = this.m_glyph.getGraphics();
         g.setPen((Pen)null);
         g.setBrush(this.m_controlBrush);
         g.drawRect(0, 0, nInnerWidth, nInnerHeight);
         g.setPen(new Pen(colorPen));

         for(int i = 0; i < nMinDimension / 2; ++i) {
            g.drawLine(nXOffset + i, nYOffset + i, nXOffset + i, nYOffset + (nMinDimension - i));
         }
      } else if (this.m_new) {
         this.m_edit = false;
         this.m_glyph = new Bitmap(this.m_width - 4, this.m_height - 4);
         Graphics g = this.m_glyph.getGraphics();
         g.setPen((Pen)null);
         g.setBrush(this.m_controlBrush);
         g.drawRect(0, 0, this.m_width - 4, this.m_height - 4);
         g.setPen(new Pen(colorPen));
         if (nMinDimension == nInnerWidth) {
            nYOffset += 2;
         } else {
            nXOffset += 2;
         }

         nMinDimension -= 4;
         g.drawLine(nXOffset, nYOffset, nXOffset + nMinDimension + 1, nYOffset + nMinDimension + 1);
         g.drawLine(nXOffset + nMinDimension / 2, nYOffset, nXOffset + nMinDimension / 2, nYOffset + nMinDimension + 1);
         g.drawLine(nXOffset + nMinDimension, nYOffset, nXOffset - 1, nYOffset + nMinDimension + 1);
         g.drawLine(nXOffset, nYOffset + nMinDimension / 2, nXOffset + nMinDimension + 1, nYOffset + nMinDimension / 2);
      } else if (this.m_edit) {
         this.m_glyph = new Bitmap(this.m_width - 4, this.m_height - 4);
         Graphics g = this.m_glyph.getGraphics();
         g.setPen((Pen)null);
         g.setBrush(this.m_controlBrush);
         g.drawRect(0, 0, this.m_width - 4, this.m_height - 4);
         g.setPen(new Pen(colorPen));
         g.drawLine(nXOffset, nYOffset, nXOffset + nMinDimension, nYOffset + nMinDimension);
      }

   }

   protected RowSelectorDisplayer() {
      this.m_controlBrush = new Brush(Color.CONTROL);
      this.m_rect = new RECT();
      this.m_imageDisplayer.setAlignment(68);
      this.setCurrentRow(false);
      this.setNewRow(false);
      this.setEditRow(false);
   }

   public void paintIn(Graphics graphics, Rectangle bounds, Rectangle clipRect, CustomDrawData data) {
      RowSelectorDrawData rowData = (RowSelectorDrawData)data;
      this.paintIn(graphics, bounds, clipRect);
   }

   public void paintIn(Graphics graphics, Rectangle bounds, Rectangle clipRect) {
      RECT rc = this.m_rect;
      rc.left = bounds.x;
      rc.top = bounds.y;
      rc.right = bounds.x + bounds.width;
      rc.bottom = bounds.y + bounds.height;
      Windows.DrawEdge(graphics.getHandle(), rc, 5, 15);
      bounds.x += 2;
      bounds.y += 2;
      bounds.width -= 4;
      bounds.height -= 4;
      if (this.m_glyph != null) {
         this.m_imageDisplayer.paintIn(graphics, bounds, clipRect, this.m_glyph, new Point(this.m_width - 4, this.m_height - 4));
      } else {
         graphics.setBrush(this.m_controlBrush);
         graphics.setPen((Pen)null);
         graphics.drawRect(bounds);
      }

   }

   public boolean isNewRow() {
      return this.m_new;
   }

   public void setCurrentRow(boolean current) {
      if (this.m_current != current) {
         this.m_current = current;
         this.updateGlyph();
      }

   }

   public void setSize(int width, int height) {
      if (this.m_width != width || this.m_height != height) {
         this.m_width = width;
         this.m_height = height;
         this.updateGlyph();
      }

   }

   public void eventHandler(RowSelectorDrawEvent event) {
      this.paintIn(event.graphics, event.bounds, event.clipRect, event.data);
   }

   public boolean isCurrentRow() {
      return this.m_current;
   }

   public void setEditRow(boolean bIsEdit) {
      if (this.m_edit != bIsEdit) {
         this.m_edit = bIsEdit;
         this.updateGlyph();
      }

   }
}
