package icontrols.DataGrid;

import com.ms.wd.ui.Control;
import com.ms.wd.ui.Rectangle;
import com.ms.wd.util.Debug;
import com.ms.wd.util.List;
import icontrols.Data.DataProvider;
import icontrols.Data.DataRow;

class Selection {
   private List m_ranges = new List();
   private List m_removedRanges = new List();
   private int m_type = 3;

   public void updateSelections(DataGrid grid) {
      for(int i = 0; i < this.m_removedRanges.getSize(); ++i) {
         SelectionRange currentRange = (SelectionRange)this.m_removedRanges.getItem(i);
         if (currentRange != null) {
            this.updateSelectionRange(grid, currentRange);
         }
      }

      this.m_removedRanges.removeAllItems();

      for(int i = 0; i < this.m_ranges.getSize(); ++i) {
         SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
         if (currentRange.m_dirty) {
            this.updateSelectionRange(grid, currentRange);
         }
      }

      SelectionRange ideal = null;

      for(int i = this.m_ranges.getSize() - 1; i >= 0; --i) {
         SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
         if (currentRange.m_idealRange != null) {
            if (ideal == null) {
               ideal = currentRange.m_idealRange;
               currentRange.m_idealRange.m_dirty = false;
            }

            this.m_ranges.removeItem(i);
         }
      }

      if (ideal != null) {
         this.m_ranges.addItem(ideal);
      }

   }

   public boolean isCellSelected(int column, DataRow row) {
      boolean selected = false;

      for(int i = 0; i < this.m_ranges.getSize(); ++i) {
         SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
         if (currentRange.isCellInRange(column, row)) {
            selected = true;
            break;
         }
      }

      return selected;
   }

   public void clearSelection() {
      if (this.m_ranges.getSize() > 0) {
         this.m_removedRanges.addItems(this.m_ranges);
         this.m_ranges.removeAllItems();
      }

   }

   private void forceRangeType(int nType) {
      if (this.m_type != nType) {
         this.clearSelection();
         this.m_type = nType;
      }

   }

   public boolean isRowSelected(DataRow row) {
      return this.isCellSelected(-1, row);
   }

   public void deselectRow(DataRow row) {
      for(int i = 0; i < this.m_ranges.getSize(); ++i) {
         SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
         if (currentRange.isCellInRange(-1, row)) {
            this.m_removedRanges.addItem(this.m_ranges.removeItem(i));
            break;
         }
      }

   }

   public void deselectColumn(int nColumn) {
      for(int i = 0; i < this.m_ranges.getSize(); ++i) {
         SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
         if (currentRange.isCellInRange(nColumn, (DataRow)null)) {
            this.m_removedRanges.addItem(this.m_ranges.removeItem(i));
            break;
         }
      }

   }

   private void updateSelectionRange(DataGrid grid, SelectionRange range) {
      Debug.assert(grid != null && range != null, "Invalid parameters");
      if (range.m_type == 2) {
         Column column = grid.getInternalColumn(range.m_leftColumn);
         Rectangle inside = grid.getCachedClientInsideRect();
         ((Control)grid).invalidateRect(new Rectangle(column.m_x, inside.y, column.m_width, inside.height));
         ((Control)grid).update();
      } else if (range.m_type == 1) {
         Rectangle bounds = grid.getCellBounds(grid.getFirstVisibleColumn(), range.m_topRow);
         if (bounds != null) {
            Rectangle inside = grid.getCachedClientInsideRect();
            bounds.x = inside.x;
            bounds.width = inside.width;
            ((Control)grid).invalidateRect(bounds);
            ((Control)grid).update();
         }
      }

      range.m_dirty = false;
   }

   public int[] getColumns() {
      int[] columns = null;
      if (this.m_type == 2 && this.m_ranges.getSize() > 0) {
         columns = new int[this.m_ranges.getSize()];

         for(int i = 0; i < this.m_ranges.getSize(); ++i) {
            SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
            columns[i] = currentRange.m_leftColumn;
         }
      }

      return columns;
   }

   public void selectRow(DataRow row) {
      boolean bNeedNewRange = true;
      this.forceRangeType(1);
      if (!this.isCellSelected(-1, row)) {
         for(int i = 0; i < this.m_removedRanges.getSize(); ++i) {
            SelectionRange currentRange = (SelectionRange)this.m_removedRanges.getItem(i);
            if (currentRange.m_type == 1 && currentRange.m_leftColumn == -1 && DataProvider.rowsEqual(currentRange.m_topRow, row) && currentRange.m_rightColumn == -1 && DataProvider.rowsEqual(currentRange.m_bottomRow, row)) {
               bNeedNewRange = false;
               this.m_ranges.addItem(this.m_removedRanges.removeItem(i));
               currentRange.m_rows = new DataRow[]{row};
               break;
            }
         }

         if (bNeedNewRange) {
            SelectionRange newRange = null;
            newRange = new SelectionRange(row);
            this.m_ranges.addItem(newRange);
         }
      }

   }

   public boolean isColumnSelected(int column) {
      return this.isCellSelected(column, (DataRow)null);
   }

   public DataRow[] getRows() {
      DataRow[] rows = null;
      if (this.m_type == 1 && this.m_ranges.getSize() > 0) {
         rows = new DataRow[this.m_ranges.getSize()];

         for(int i = 0; i < this.m_ranges.getSize(); ++i) {
            SelectionRange currentRange = (SelectionRange)this.m_ranges.getItem(i);
            rows[i] = currentRange.m_rows[0];
         }
      }

      return rows;
   }

   public void selectColumn(int nColumn) {
      boolean bNeedNewRange = true;
      this.forceRangeType(2);
      if (!this.isCellSelected(nColumn, (DataRow)null)) {
         for(int i = 0; i < this.m_removedRanges.getSize(); ++i) {
            SelectionRange currentRange = (SelectionRange)this.m_removedRanges.getItem(i);
            if (currentRange.m_type == 2 && currentRange.m_leftColumn == nColumn && currentRange.m_topRow == null && currentRange.m_rightColumn == nColumn && currentRange.m_bottomRow == null) {
               bNeedNewRange = false;
               this.m_ranges.addItem(this.m_removedRanges.removeItem(i));
               break;
            }
         }

         if (bNeedNewRange) {
            SelectionRange newRange = null;
            newRange = new SelectionRange(nColumn);
            this.m_ranges.addItem(newRange);
         }
      }

   }
}
